@@ -248,17 +248,17 @@
 #define INSTALL_SBINDIR "/usr/local/mysql/bin"
 #define INSTALL_BINDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLSHAREDIR "/usr/local/mysql/share/mysql"
-#define INSTALL_SHAREDIR "/usr/local/mysql/share/mysql"
+#define INSTALL_SHAREDIR "/usr/local/mysql/share"
 #define INSTALL_PLUGINDIR "/usr/local/mysql/lib/mysql/plugin"
 #define INSTALL_INCLUDEDIR "/usr/local/mysql/include/perconaserver"
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.21-20/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.21-20/plugin/keyring_vault/tests;/build/percona-server/src/percona-server-5.7.21-20/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.21-20/plugin/scalability_metrics/tests"
-#define INSTALL_INFODIR "/usr/local/mysql/share/mysql/docs"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.21-21/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.21-21/plugin/keyring_vault/tests;/build/percona-server/src/percona-server-5.7.21-21/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.21-21/plugin/scalability_metrics/tests"
+#define INSTALL_INFODIR "/usr/local/mysql/share/doc/percona-server"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
-#define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/mysql"
-#define INSTALL_DOCDIR "/usr/local/mysql/share/mysql/docs"
+#define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/doc/percona-server"
+#define INSTALL_DOCDIR "/usr/local/mysql/share/doc/percona-server"
 #define INSTALL_MANDIR "/usr/local/mysql/share/man"
 #define INSTALL_SUPPORTFILESDIR "/usr/local/mysql/share/mysql"
 #define INSTALL_LIBDIR "/usr/local/mysql/lib"
@@ -291,8 +291,8 @@
 /*
  * Character sets
  */
-#define MYSQL_DEFAULT_CHARSET_NAME "utf8"
-#define MYSQL_DEFAULT_COLLATION_NAME "utf8_general_ci"
+#define MYSQL_DEFAULT_CHARSET_NAME "utf8mb4"
+#define MYSQL_DEFAULT_COLLATION_NAME "utf8mb4_unicode_ci"
 /* #undef HAVE_CHARSET_armscii8 */
 /* #undef HAVE_CHARSET_ascii */
 #define HAVE_CHARSET_big5 1
@@ -392,14 +392,14 @@
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
 #define MYSQL_VERSION_PATCH 21
-#define MYSQL_VERSION_EXTRA "-20"
+#define MYSQL_VERSION_EXTRA "-21"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.21-20"
+#define PACKAGE_STRING "MySQL Server 5.7.21-21"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.21-20"
-#define VERSION "5.7.21-20"
+#define PACKAGE_VERSION "5.7.21-21"
+#define VERSION "5.7.21-21"
 #define PROTOCOL_VERSION 10
 
 /*
@@ -407,6 +407,7 @@
  */
 #define CPU_LEVEL1_DCACHE_LINESIZE 64
 
+
 /*
  * NDB
  */
